@@ -1,13 +1,18 @@
 package Dist::Zilla::Plugin::PodWeaver;
 BEGIN {
-  $Dist::Zilla::Plugin::PodWeaver::VERSION = '3.101530';
+  $Dist::Zilla::Plugin::PodWeaver::VERSION = '3.101620';
 }
 # ABSTRACT: weave your Pod together from configuration and Dist::Zilla
 use Moose;
 use Moose::Autobox;
 use List::MoreUtils qw(any);
 use Pod::Weaver 3.100710; # logging with proxies
-with 'Dist::Zilla::Role::FileMunger';
+with(
+  'Dist::Zilla::Role::FileMunger',
+  'Dist::Zilla::Role::FileFinderUser' => {
+    default_finders => [ ':InstallModules', ':ExecFiles' ],
+  },
+);
 
 use namespace::autoclean;
 
@@ -51,15 +56,17 @@ has config_plugin => (
   isa => 'Str',
 );
 
+sub munge_files {
+  my ($self) = @_;
+  
+  $self->munge_file($_) for @{ $self->found_files };
+} 
+
 sub munge_file {
   my ($self, $file) = @_;
 
   $self->log_debug([ 'weaving pod in %s', $file->name ]);
 
-  return
-    unless $file->name =~ /\.(?:pm|pod)$/i
-    and ($file->name !~ m{/} or $file->name =~ m{^lib/});
-
   $self->munge_pod($file);
   return;
 }
@@ -115,7 +122,7 @@ Dist::Zilla::Plugin::PodWeaver - weave your Pod together from configuration and
 
 =head1 VERSION
 
-version 3.101530
+version 3.101620
 
 =head1 DESCRIPTION
 
